-- Author:RedFoxModding
-- Name:FruitsAdjustment
-- Version: 1.0.1.0
-- Development: Nov.20 - Feb.21
-- Date: 04.02.2021


--ToDo V2:
-- Adjust Forageharvester Factors for cereal
-- Query if energiemais is used
-- many ideas in my head including green fodder, precisionFarming and SeasonsGeo ;)

--ChangeLog V1.0.1.0
-- Straw price fixed
-- Incarase_grass windrow yield fixed
-- Added dependency of yield and price in hardcore mode 
-- Added data of millet, horsegrass, pasturegrass, miscanthus in seedUsage

FruitsAdjustment = {};

function FruitsAdjustment:loadMap(name)
	print("FruitsAdjustment FS19 by RedFoxModding loaded");
	
	-- All values are based on average statistics raised in region Germany.
	-- To optimise gameplay the data of these fruits were converted from reality to the game and factors such as effort for cultivation and harvest were included.
	
	--You can switch to Hardcore Mode just by changing the local realism value to 0.5
	--This means that the yield is very close to real life. Default setting is 1, that game mechanics like animal feeding or productions didnt get destroyed.
	
	local realismFactor = 1;				-- Change to 0.5 to switch to Hardcore-Mode
	
	-- yield and price are in linear dependency, so the priceFactor is 1/realismFactor
	local priceFactor = 1/realismFactor;	-- factor for cellprices, no changes needed 
	local seedUsage = {};					-- Seedusage 		L/m2
	local literPerSqm = {};					-- Yield 			L/m2
	local litersPerSqm = {};				-- Windrow Yield	L/m2
	local pricePerLiter = {};				-- Sellprice		€/L
	
	--You can deactivate single Data by commenting out using --
	--For Example:
	--seedUsage.Cotton = 0.01; 
	
	--You can add your Fruits like:
	--Seedusage: 		seedUsage.FRUITTYPE = YOUR Number;
	--Yield: 			literPerSqm.FRUITTYPE = YOUR Number;
	--Windrow Yield:	litersPerSqm.FRUITTYPE = YOUR Number;
	--Sellprice:		pricePerLiter.FRUITTYPE = YOUR Number;
	
	--The code will skip values for fruits that are not included into your map
	--Check the FruitTypes.xml of your map for the right name of FRUITTYPE 
	
	--Seedusage in L/m2 per Fruit
	seedUsage.WHEAT = 0.037;
	seedUsage.BARLEY = 0.042;
	seedUsage.OAT = 0.043;
	seedUsage.RYE = 0.037;
	seedUsage.SPELT = 0.043;
	seedUsage.TRITICALE = 0.04;
	seedUsage.MILLET = 0.035;
	seedUsage.CANOLA = 0.012;
	seedUsage.MAIZE = 0.015;
	seedUsage.ENERGIEMAIZE = 0.015;
	seedUsage.SUNFLOWER = 0.013;
	seedUsage.SOYBEAN = 0.014;
	seedUsage.POPPY = 0.013;
	seedUsage.FIELDBEAN = 0.014;
	seedUsage.POTATO = 0.35;
	seedUsage.SUGARBEET = 0.018;
	seedUsage.CABBAGE = 0.019;
	seedUsage.REDCABBAGE = 0.019;
	seedUsage.LETTUCE = 0.018;
	seedUsage.CARROT = 0.017;
	seedUsage.ONION = 0.016;
	seedUsage.OILSEEDRADISH = 0.008;
	seedUsage.GRASS = 0.025;
	seedUsage.ALFALFA = 0.021;
	seedUsage.CLOVER = 0.023;
	seedUsage.INCARASE_GRASS = 0.03;
	seedUsage.FIELDGRASS = 0.03;
	seedUsage.HORSEGRASS = 0.026;
	seedUsage.PASTUREGRASS = 0.022;
	seedUsage.MISCANTHUS = 0.023;
	
	--Yield in L/m2 per Fruit
    literPerSqm.WHEAT = 0.9375;
	literPerSqm.BARLEY = 0.923;
	literPerSqm.OAT = 0.933;
	literPerSqm.RYE = 0.786;
	literPerSqm.SPELT = 0.875;
	literPerSqm.TRITICALE = 1.077;
	literPerSqm.CANOLA = 0.586;
	literPerSqm.MAIZE = 1.0;
	literPerSqm.ENERGIEMAIZE = 0.8;
	literPerSqm.SUNFLOWER = 0.857;
	literPerSqm.SOYBEAN = 0.5485;
	literPerSqm.POPPY = 0.4;
	literPerSqm.FIELDBEAN = 0.625;
	--literPerSqm.POTATO = 4.13;		--Standardwert, keine Änderung nötig
	--literPerSqm.SUGARBEET = 5.78;		--Standardwert, keine Änderung nötig
	literPerSqm.CABBAGE = 7.857;
	literPerSqm.REDCABBAGE = 7.857;
	literPerSqm.LETTUCE = 7.857;
	literPerSqm.CARROT = 7.14;
	literPerSqm.ONION = 5.14;
	literPerSqm.GRASS = 2.5;
	literPerSqm.ALFALFA = 4.0;
	literPerSqm.CLOVER = 2.5;
	literPerSqm.INCARASE_GRASS = 0.5625;
	literPerSqm.FIELDGRASS = 4.5;
	literPerSqm.MILLET = 0.2950
	
	--Windrow Yield in L/m2 per Fruit
	litersPerSqm.WHEAT = 2.95;
	litersPerSqm.BARLEY = 2.75;
	litersPerSqm.OAT = 2.7;
	litersPerSqm.RYE = 2.75;
	litersPerSqm.SPELT = 2.6;
	litersPerSqm.TRITICALE = 2.9;
	litersPerSqm.INCARASE_GRASS = 1.8;
	litersPerSqm.MILLET = 1;
	
	--Sellprice in €/L per Filltype
	pricePerLiter.WHEAT = 0.56;
	pricePerLiter.BARLEY = 0.56;
	pricePerLiter.OAT = 0.56;
	pricePerLiter.RYE = 0.66;
	pricePerLiter.SPELT = 0.6;
	pricePerLiter.TRITICALE = 0.45;
	pricePerLiter.CANOLA = 0.89;
	pricePerLiter.MAIZE = 0.45;
	--pricePerLiter.ENERGIEMAIZE = 0.1;
	pricePerLiter.SUNFLOWER = 0.61;
	pricePerLiter.SOYBEAN = 0.95;
	pricePerLiter.POPPY = 1.3;
	pricePerLiter.FIELDBEAN = 0.83;
	pricePerLiter.POTATO = 0.17;
	pricePerLiter.SUGARBEET = 0.12;
	pricePerLiter.CABBAGE = 0.09;
	pricePerLiter.REDCABBAGE = 0.09;
	pricePerLiter.LETTUCE = 0.09;
	pricePerLiter.CARROT = 0.1;
	pricePerLiter.ONION = 0.14;
	pricePerLiter.INCARASE_GRASS = 0.62;
	pricePerLiter.MILLET = 1.77;
	
	--other Filltypes in €/L
	pricePerLiter.MILK = 0.5;
	pricePerLiter.DIGESTATE = 0.033;
	pricePerLiter.STRAW = 0.06;

-- ******************************************** DO NOT CHANGE ANYTHING DOWN UNDER *******************************************************
	
	if realismFactor == 1 then
		print("FruitsAdjustment: You re using default settings");
	end;
	if realismFactor < 1 then
		print("FruitsAdjustment: You re using the Hardcore-Mode, respect!");
	end;
	if realismFactor > 1 then
		print("FruitsAdjustment: You re using my script to cheat, shame on you!");
	end;
	
    for k, v in pairs(g_currentMission.fruitTypeManager.fruitTypes) do
		if seedUsage[v.name] ~= nil then
			v.seedUsagePerSqm = seedUsage[v.name];
			--print("FruitsAdjustment: "..tostring(v.name).." Seed usage changed to "..tostring(v.seedUsagePerSqm*10000).." Liters per ha.");
		end;
		if literPerSqm[v.name] ~= nil then
			v.literPerSqm = literPerSqm[v.name]*realismFactor;
			--print("FruitsAdjustment: "..tostring(v.name).." Yield changed to "..tostring(v.literPerSqm*10000).." Liters per ha.");
		end;
		if litersPerSqm[v.name] ~= nil then
			v.litersPerSqm = litersPerSqm[v.name]*realismFactor;
			--print("FruitsAdjustment: "..tostring(v.name).." Windrow Yield changed to "..tostring(v.litersPerSqm*10000).." Liters per ha.");
		end;
	end;
	
	print("FruitsAdjustment: Fruits adjusted")
	
	for m, w in pairs(g_currentMission.fillTypeManager.fillTypes) do
		if pricePerLiter[w.name]~= nil then
			w.pricePerLiter = pricePerLiter[w.name]*priceFactor;
			--print("FruitsAdjustment: "..tostring(w.name).." Sellprice changed to "..tostring(w.pricePerLiter*1000).." Euro per 1000L.");
		end;
	end;
	
	print("FruitsAdjustment: Filltypes adjusted")
	print("FruitsAdjustment: Everything is adjusted - Have fun :)")
end;




function FruitsAdjustment:keyEvent(unicode, sym, modifier, isDown)
end;
function FruitsAdjustment:update(dt)
end;
function FruitsAdjustment:draw()
end;
function FruitsAdjustment:deleteMap()
end;
function FruitsAdjustment:mouseEvent(posX, posY, isDown, isUp, button)
end;

addModEventListener(FruitsAdjustment);
